aboutsummaryrefslogtreecommitdiff
path: root/contrib/unbound/respip/respip.h
diff options
context:
space:
mode:
Diffstat (limited to 'contrib/unbound/respip/respip.h')
-rw-r--r--contrib/unbound/respip/respip.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/contrib/unbound/respip/respip.h b/contrib/unbound/respip/respip.h
index 988a72263390..e4ab5cc9cce3 100644
--- a/contrib/unbound/respip/respip.h
+++ b/contrib/unbound/respip/respip.h
@@ -251,11 +251,13 @@ int respip_set_is_empty(const struct respip_set* set);
* @param local_alias: set to a local alias if the query matches an alias in
* a local zone. In this case its owner name will be considered the actual
* query name.
* @param repinfo: reply info containing the client's source address and port.
*/
void respip_inform_print(struct respip_action_info* respip_actinfo,
uint8_t* qname, uint16_t qtype, uint16_t qclass,
- struct local_rrset* local_alias, struct comm_reply* repinfo);
+ struct local_rrset* local_alias, struct sockaddr_storage* addr,
+ socklen_t addrlen);
/**
* Find resp_addr in tree, create and add to tree if it does not exist.
@@ -251,11 +251,13 @@ int respip_set_is_empty(const struct respip_set* set);
* a local zone. In this case its owner name will be considered the actual
* query name.
- * @param repinfo: reply info containing the client's source address and port.
+ * @param addr: the client's source address and port.
+ * @param addrlen: the client's source address length.
*/
void respip_inform_print(struct respip_action_info* respip_actinfo,